:github_url: https://github.com/stephane-caron/pink/tree/master/doc/src/tasks.rst

*****
Tasks
*****

Generic task
============

.. automodule:: pink.tasks.task
    :members:

Body task
=========

.. automodule:: pink.tasks.body_task
    :members:

Posture task
============

.. automodule:: pink.tasks.posture_task
    :members:
